==> fred_ferda_auction-0.3.0rc1.tar.gz: fred_ferda_auction-0.3.0rc1/jest.config.js <==
module.exports = {
    testEnvironment: '<rootDir>/tests-js/helpers/jsdom-with-time-zone.js',
    testMatch: ['<rootDir>/tests-js/**/*.test.js'],
    moduleFileExtensions: ['js', 'vue'],
    transform: {
        '^.+\\.js$': 'babel-jest',
        '^.+\\.vue$': '@vue/vue2-jest',
    },
    snapshotSerializers: ['<rootDir>/node_modules/jest-serializer-vue'],
    transformIgnorePatterns: ['node_modules/(?!(@cz-nic/fred-ferda))'],
    moduleNameMapper: {
        '\\.(jpg|jpeg|png|gif|eot|otf|webp|svg|ttf|woff|woff2|mp4|webm|wav|mp3|m4a|aac|oga)$':
            '<rootDir>/tests-js/__mocks__/fileMock.js',
        '\\.(css|less)$': 'identity-obj-proxy',
        '^ferda_auction_test/(.*)$': '<rootDir>/tests-js/$1',
        '^ferda_auction/(.*)$': '<rootDir>/assets/js/components/$1',
        '^~ferda_auction_css/(.*)$': '<rootDir>/assets/scss/$1',
        '^ferda_auction_js/(.*)$': '<rootDir>/assets/js/$1',
        '^ferda/(.*)$': '<rootDir>/node_modules/@cz-nic/fred-ferda/assets/js/components/$1',
        '^~FerdaCSS/(.*)$': '<rootDir>/node_modules/@cz-nic/fred-ferda/assets/scss/$1',
        '^~FerdaJS/(.*)$': '<rootDir>/node_modules/@cz-nic/fred-ferda/assets/js/$1',
        '^ferda_test/(.*)$': '<rootDir>/node_modules/@cz-nic/fred-ferda/tests-js/$1',
    },
    setupFilesAfterEnv: [
        '<rootDir>/tests-js/helpers/setup-vue.js',
        '<rootDir>/tests-js/helpers/override-errors.js',
        '<rootDir>/tests-js/helpers/polyfill.js',
    ],
    collectCoverage: true,
    collectCoverageFrom: [
        'assets/js/**/*.{js,vue}',
        '!assets/js/main.js',
        '!assets/js/main.config.js',
        '!assets/js/utils.js',
        '!assets/js/store.js',
        '!assets/js/router/**/*.js',
        '!assets/js/constants.js',
        '!assets/js/Urls.js',
        '!assets/js/auctionClient.js',
        '!assets/js/utils/**/*.js',
        '!assets/js/logout.js',
        '!assets/js/navigation.js',

        // Contains shared datetime pickers from ferda, causes weird jest errors
        '!assets/js/components/form/AuctionListSearchForm.vue',
        '!assets/js/components/list/AuctionList.vue',
        '!assets/js/components/list/AuctionListWinners.vue',
    ],
    coverageDirectory: 'coverage-js',
    coverageReporters: ['text', 'text-summary', 'json-summary'],
    coverageProvider: 'v8',
}

==> fred_ferda_auction-0.5.0rc3.tar.gz: fred_ferda_auction-0.5.0rc3/jest.config.js <==
module.exports = {
    testEnvironment: '<rootDir>/tests-js/helpers/jsdom-with-time-zone.js',
    testMatch: ['<rootDir>/tests-js/**/*.test.js'],
    moduleFileExtensions: ['js', 'vue'],
    transform: {
        '^.+\\.js$': 'babel-jest',
        '^.+\\.vue$': '@vue/vue2-jest',
    },
    snapshotSerializers: ['<rootDir>/node_modules/jest-serializer-vue'],
    transformIgnorePatterns: ['node_modules/(?!(@cz-nic/fred-ferda))'],
    moduleNameMapper: {
        '\\.(jpg|jpeg|png|gif|eot|otf|webp|svg|ttf|woff|woff2|mp4|webm|wav|mp3|m4a|aac|oga)$':
            '<rootDir>/tests-js/__mocks__/fileMock.js',
        '\\.(css|less)$': 'identity-obj-proxy',
        '^ferda_auction_test/(.*)$': '<rootDir>/tests-js/$1',
        '^ferda_auction/(.*)$': '<rootDir>/assets/js/components/$1',
        '^~ferda_auction_css/(.*)$': '<rootDir>/assets/scss/$1',
        '^ferda_auction_js/(.*)$': '<rootDir>/assets/js/$1',
        '^ferda/(.*)$': '<rootDir>/node_modules/@cz-nic/fred-ferda/assets/js/components/$1',
        '^~FerdaCSS/(.*)$': '<rootDir>/node_modules/@cz-nic/fred-ferda/assets/scss/$1',
        '^FerdaJS/(.*)$': '<rootDir>/node_modules/@cz-nic/fred-ferda/assets/js/$1',
        '^ferda_test/(.*)$': '<rootDir>/node_modules/@cz-nic/fred-ferda/tests-js/$1',
    },
    setupFilesAfterEnv: [
        '<rootDir>/tests-js/helpers/setup-vue.js',
        '<rootDir>/tests-js/helpers/override-errors.js',
        '<rootDir>/tests-js/helpers/polyfill.js',
    ],
    collectCoverage: true,
    collectCoverageFrom: [
        'assets/js/**/*.{js,vue}',
        '!assets/js/main.js',
        '!assets/js/main.config.js',
        '!assets/js/utils.js',
        '!assets/js/store.js',
        '!assets/js/router/**/*.js',
        '!assets/js/constants.js',
        '!assets/js/Urls.js',
        '!assets/js/auctionClient.js',
        '!assets/js/utils/**/*.js',
        '!assets/js/logout.js',
        '!assets/js/navigation.js',

        // Contains shared datetime pickers from ferda, causes weird jest errors
        '!assets/js/components/form/AuctionListSearchForm.vue',
        '!assets/js/components/list/AuctionList.vue',
        '!assets/js/components/list/AuctionListWinners.vue',
    ],
    coverageDirectory: 'coverage-js',
    coverageReporters: ['text', 'text-summary', 'json-summary'],
    coverageProvider: 'v8',
}
